<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_Section
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_Section extends Moc10_Form
{

    /**
     * Form templates
     * @var array
     */
    protected $_templates = array('main' => null, 'mobile' => null);

    /**
     * $_POST fields
     * @var array
     */
    protected $_postFields = array('plugin' => null,
                                   'site_id' => null,
                                   'template_id' => null,
                                   'parent_section_id' => null,
                                   'section_title' => null,
                                   'section_url' => null,
                                   'short_template' => null,
                                   'short_template_container' => null,
                                   'short_limit' => 0,
                                   'long_template' => null,
                                   'long_template_container' => null,
                                   'long_limit' => 0,
                                   'sort_order1' => null,
                                   'sort_order2' => null,
                                   'paginate' => null,
                                   'section_access' => null,
                                   'cur_site_id' => null,
                                   'cur_section_url' => null,
                                   'mobile' => null,
                                   'section_id' => 0);

    /**
     * Initialization method for the section form.
     *
     * @param  array $post
     * @return void
     */
    public function init($post = null)
    {

        $lang = new Phire_Language();

        $this->_setFields($post);
        $this->_setTemplates();

        $this->setAttributes('id', 'addSectionForm');

        $sess = Moc10_Session::getInstance();
        $sitesAry = Phire_Sites::getAllowedSites(true);

        $tmpls = new Phire_Table_Templates();
        $sects = new Phire_Table_Sections();
        if ($this->_postFields['site_id'] == 0) {
            $tmpls->findAll('template_id ASC', 'site_id', $sitesAry['first_site_id']);
            $sects->findAll('section_id ASC', 'site_id', $sitesAry['first_site_id']);
        } else {
            $tmpls->findAll('template_id ASC', 'site_id', $this->_postFields['site_id']);
            $sects->findAll('section_id ASC', 'site_id', $this->_postFields['site_id']);
        }
        $tmplAry = array('0' => '(' . $lang->__('None') . ')');
        foreach ($tmpls->rows as $tmpl) {
            if (in_array($tmpl->site_id, $sess->sites)) {
                $tmplAry[$tmpl->template_id] = $tmpl->template_name;
            }
        }
        $sectAry = array('0' => '(' . $lang->__('None') . ')');
        foreach ($sects->rows as $sect) {
            if (in_array($sect->site_id, $sess->sites) && ($sect->section_id != $this->_postFields['section_id'])) {
                $sectAry[$sect->section_id] = $sect->section_title;
            }
        }

        // Create the 'template_id' form element.
        $template_id = new Moc10_Form_Element_Select('template_id', $tmplAry, $this->_postFields['template_id']);
        $template_id->setLabel($lang->__('Template:'));
        $template_id->setAttributes('style', 'float: left;');

        // Create the 'parent_section_id' form element.
        $parent_section_id = new Moc10_Form_Element_Select('parent_section_id', $sectAry, $this->_postFields['parent_section_id']);

        // Create the 'section_title' form element.
        $section_title = new Moc10_Form_Element('text', 'section_title', $this->_postFields['section_title']);
        $section_title->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '20' : '100'));
        $section_title->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Title:') : $lang->__('Section Title:')));
        $section_title->setRequired(true);

        // Create the 'section_url' form element.
        $section_url = new Moc10_Form_Element('text', 'section_url', $this->_postFields['section_url']);
        $section_url->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '20' : '100'));
        $section_url->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('URL:') : $lang->__('Section URL:')));
        $section_url->setRequired(true);

        // If form has been submitted, validate the section URL.
        if (($this->_postFields['site_id'] != 0) && (!is_null($this->_postFields['section_url'])) && ($this->_postFields['section_url'] != $this->_postFields['cur_section_url'])) {
            $dupe_url = new Phire_Table_Sections();
            $dupe_url->execute("SELECT * FROM " . DB_PREFIX . "sections WHERE section_url = '" . (string)Moc10_String::setString($this->_postFields['section_url'])->escape()->striptags() . "' AND site_id = '" . (string)Moc10_String::setString($this->_postFields['site_id'])->escape(true)->striptags() . "' LIMIT 1");
            $dupe_page_url = new Phire_Table_Pages();
            $dupe_page_url->execute("SELECT * FROM " . DB_PREFIX . "pages WHERE page_url = '" . (string)Moc10_String::setString($this->_postFields['section_url'])->escape()->striptags() . "' AND site_id = '" . (string)Moc10_String::setString($this->_postFields['site_id'])->escape(true)->striptags() . "' LIMIT 1");
            if ((isset($dupe_url->rows[0])) || (isset($dupe_page_url->rows[0]))) {
                $section_url->addValidator('NotEqual', true, $this->_postFields['section_url'], $lang->__('That URL already exists in the system for that site. Please choose another URL.'));
            } else if ((substr($this->_postFields['section_url'], 0, strlen(BASE_PATH . SYS_PATH)) == BASE_PATH . SYS_PATH) || (substr($this->_postFields['section_url'], 0, 7) == '/search') || (substr($this->_postFields['section_url'], 0, 4) == '/feed') || (substr($this->_postFields['section_url'], 0, 5) == '/user') || (substr($this->_postFields['section_url'], 0, 7) == '/member') || (substr($this->_postFields['section_url'], 0, 4) == '/tag') || (substr($this->_postFields['section_url'], 0, 8) == '/captcha')) {
                $section_url->addValidator('NotEqual', true, $this->_postFields['section_url'], $lang->__('That URL is a reserved system URL. Please choose another URL.'));
            }
        }

        if (($this->_postFields['site_id'] != 0) && (!is_null($this->_postFields['section_url'])) && ($this->_postFields['site_id']  != $this->_postFields['cur_site_id'])) {
            $dupe_site_url = new Phire_Table_Sections();
            $dupe_site_url->execute("SELECT * FROM " . DB_PREFIX . "sections WHERE section_url = '" . (string)Moc10_String::setString($this->_postFields['section_url'])->escape()->striptags() . "' AND site_id = '" . (string)Moc10_String::setString($this->_postFields['site_id'])->escape(true)->striptags() . "' LIMIT 1");
            if (isset($dupe_site_url->rows[0])) {
                $section_url->addValidator('NotEqual', true, $this->_postFields['section_url'], $lang->__('That URL already exists in the system for that site. Please choose another URL.'));
            } else if ((substr($this->_postFields['section_url'], 0, strlen(BASE_PATH . SYS_PATH)) == BASE_PATH . SYS_PATH) || (substr($this->_postFields['section_url'], 0, 7) == '/search') || (substr($this->_postFields['section_url'], 0, 4) == '/feed') || (substr($this->_postFields['section_url'], 0, 5) == '/user') || (substr($this->_postFields['section_url'], 0, 7) == '/member') || (substr($this->_postFields['section_url'], 0, 4) == '/tag') || (substr($this->_postFields['section_url'], 0, 8) == '/captcha')) {
                $section_url->addValidator('NotEqual', true, $this->_postFields['section_url'], $lang->__('That URL is a reserved system URL. Please choose another URL.'));
            }
        }

        $containers = array('None' => $lang->__('None'), '<ul>' => '&lt;ul&gt;', '<ol>' => '&lt;ol&gt;', '<div>' => '&lt;div&gt;', '<p>' => '&lt;p&gt;', '<table>' => '&lt;table&gt;', '<tr>' => '&lt;tr&gt;', '<td>' => '&lt;td&gt;');

        // Create the 'short_template' form element.
        $short_template = new Moc10_Form_Element_Textarea('short_template', $this->_postFields['short_template']);
        $short_template->setLabel($lang->__('Short Template:'));
        $short_template->setAttributes('cols', ((!is_null($this->_postFields['mobile'])) ? '25' : '100'));
        $short_template->setAttributes('rows', ((!is_null($this->_postFields['mobile'])) ? '4' : '6'));
        $short_template->setAttributes('spellcheck', 'false');
        $short_template->setAttributes('wrap', 'off');
        $short_template->setRequired(true);

        // Create the 'short_template_container' form element.
        $short_template_container = new Moc10_Form_Element_Select('short_template_container', $containers, $this->_postFields['short_template_container']);
        $short_template_container->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Container:') : $lang->__('Short Template Container:')));

        // Create the 'short_limit' form element.
        $short_limit = new Moc10_Form_Element('text', 'short_limit', $this->_postFields['short_limit']);
        $short_limit->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '3' : '5'));
        $short_limit->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Limit:') : $lang->__('Short Limit:')));
        $short_limit->addValidator('Num');

        // Create the 'long_template' form element.
        $long_template = new Moc10_Form_Element_Textarea('long_template', $this->_postFields['long_template']);
        $long_template->setLabel($lang->__('Long Template:'));
        $long_template->setAttributes('cols', ((!is_null($this->_postFields['mobile'])) ? '25' : '100'));
        $long_template->setAttributes('rows', ((!is_null($this->_postFields['mobile'])) ? '6' : '8'));
        $long_template->setAttributes('spellcheck', 'false');
        $long_template->setAttributes('wrap', 'off');
        $long_template->setRequired(true);

        // Create the 'long_template_container' form element.
        $long_template_container = new Moc10_Form_Element_Select('long_template_container', $containers, $this->_postFields['long_template_container']);
        $long_template_container->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Container:') : $lang->__('Long Template Container:')));

        // Create the 'long_limit' form element.
        $long_limit = new Moc10_Form_Element('text', 'long_limit', $this->_postFields['long_limit']);
        $long_limit->setAttributes('size', ((!is_null($this->_postFields['mobile'])) ? '3' : '5'));
        $long_limit->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Limit:') : $lang->__('Long Limit:')));
        $long_limit->addValidator('Num');

        // Create the 'sort_order1' form element.
        $sort_order1 = new Moc10_Form_Element_Select('sort_order1', array('ID' => 'ID', 'Title' => 'Title', 'Date' => 'Date'), $this->_postFields['sort_order1']);
        $sort_order1->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Order:') : $lang->__('Sort Order:')));

        // Create the 'sort_order21' form element.
        $sort_order2 = new Moc10_Form_Element_Select('sort_order2', array('DESC' => 'DESC', 'ASC' => 'ASC', 'DESC >= Today' => 'DESC >= Today', 'ASC >= Today' => 'ASC >= Today', 'DESC <= Today' => 'DESC <= Today', 'ASC <= Today' => 'ASC <= Today', 'RAND()' => 'RAND()'), $this->_postFields['sort_order2']);

        // Create the 'section_access' form element.
        $section_access = new Moc10_Form_Element_Select('section_access', array('Public' => 'Public', 'Private' => 'Private'), $this->_postFields['section_access']);
        $section_access->setLabel(((!is_null($this->_postFields['mobile'])) ? $lang->__('Access:') : $lang->__('Section Access:')));

        // Create the 'section_id' form element.
        $section_id = new Moc10_Form_Element('hidden', 'section_id', $this->_postFields['section_id']);

        // Create the 'cur_site_id' form element.
        $cur_site_id = new Moc10_Form_Element('hidden', 'cur_site_id', $this->_postFields['cur_site_id']);

        // Create the 'cur_section_url' form element.
        $cur_section_url = new Moc10_Form_Element('hidden', 'cur_section_url', $this->_postFields['cur_section_url']);

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('SAVE'));
        $submit->setAttributes('style', 'float: right;');

        // Set whether it's a mobile form template or not.
        if (!is_null($this->_postFields['mobile'])) {
            $sess = Moc10_Session::getInstance();
            $parent_section_id->setLabel($lang->__('Parent:'));
            $submit->setAttributes('class', 'submitBtn');
            $site_id = new Moc10_Form_Element('hidden', 'site_id', $sess->cur_site_id);
            $this->setTemplate($this->_templates['mobile']);
        } else {
            $this->setAttributes('onsubmit', "return addSectionFrm.validate();");
            $site_id = new Moc10_Form_Element_Select('site_id', $sitesAry['sites'], $this->_postFields['site_id']);
            $submit->setAttributes('class', 'submitBtn');
            $parent_section_id->setLabel($lang->__('Parent Section:'));
            $site_id->setLabel($lang->__('Add to Site:'));
            $site_id->setAttributes('onchange', "xmlhttp.getRequest('../core/process/check.site.php?site_id=' + this.value + '&section_id=' + addSectionFrm.fo.section_id.value, addSectionFrm.changeURLSeparator); return false;");
            $section_title->setAttributes('style', 'width: 530px;');
            $section_url->setAttributes('style', 'width: 530px;');
            $short_template->setAttributes('style', 'width: 530px;');
            $long_template->setAttributes('style', 'width: 530px;');
            if ($this->_postFields['section_id'] == 0) {
                $section_title->setAttributes('onkeyup', "addSectionFrm.convertURL('section_title', 'section_url', '" . $sitesAry['title_sep'] . "'); xmlhttp.getRequest('../core/process/check.section.url.php?current=" . $this->_postFields['cur_section_url'] . "&url=' + addSectionFrm.fo.section_url.value + '&site_id=' + addSectionFrm.fo.site_id.value, addSectionFrm.checkURL); return false;");
            } else {
                $section_url->setAttributes('onkeyup', "xmlhttp.getRequest('../core/process/check.section.url.php?current=" . $this->_postFields['cur_section_url'] . "&url=' + addSectionFrm.fo.section_url.value + '&site_id=' + addSectionFrm.fo.site_id.value, addSectionFrm.checkURL); return false;");
            }
            $this->setTemplate($this->_templates['main']);
        }

        // Add the form element objects to the form.
        $this->addElements(array($site_id, $template_id, $parent_section_id, $section_title, $section_url, $short_template, $short_template_container, $short_limit, $long_template, $long_template_container, $long_limit, $sort_order1, $sort_order2, $section_access, $submit, $cur_site_id, $cur_section_url, $section_id));

    }

    /**
     * Method to save the section data.
     *
     * @return void
     */
    public function saveData()
    {

        if (is_array($this->_postFields['paginate']) && (isset($this->_postFields['paginate'][0])) && ($this->_postFields['paginate'][0] == 'Yes')) {
            $paginate = 'Yes';
        } else if ($this->_postFields['paginate'] == 'Yes') {
            $paginate = 'Yes';
        } else {
            $paginate = 'No';
        }

        // Edit the existing section.
        if ($this->_postFields['section_id'] != 0) {

            $section = new Phire_Table_Sections();
            $section->findById($this->_postFields['section_id']);

            $section->site_id = $this->_postFields['site_id'];
            $section->template_id = $this->_postFields['template_id'];
            $section->parent_section_id = $this->_postFields['parent_section_id'];
            $section->section_title = $this->_postFields['section_title'];
            $section->section_url = $this->_postFields['section_url'];
            $section->short_template = $this->_postFields['short_template'];
            $section->short_template_container = $this->_postFields['short_template_container'];
            $section->short_limit = (($this->_postFields['short_limit'] != '') ? $this->_postFields['short_limit'] : 0);
            $section->long_template = $this->_postFields['long_template'];
            $section->long_template_container = $this->_postFields['long_template_container'];
            $section->long_limit = (($this->_postFields['long_limit'] != '') ? $this->_postFields['long_limit'] : 0);
            $section->sort_order = $this->_postFields['sort_order1'] . '|' . $this->_postFields['sort_order2'];
            $section->paginate = $paginate;
            $section->section_access = $this->_postFields['section_access'];

        // Else, save new section.
        } else {

            $fields = array('site_id' => $this->_postFields['site_id'],
                            'template_id' => $this->_postFields['template_id'],
                            'parent_section_id' => $this->_postFields['parent_section_id'],
                            'section_title' => $this->_postFields['section_title'],
                            'section_url' => $this->_postFields['section_url'],
                            'short_template' => $this->_postFields['short_template'],
                            'short_template_container' => $this->_postFields['short_template_container'],
                            'short_limit' => (($this->_postFields['short_limit'] != '') ? $this->_postFields['short_limit'] : 0),
                            'long_template' => $this->_postFields['long_template'],
                            'long_template_container' => $this->_postFields['long_template_container'],
                            'long_limit' => (($this->_postFields['long_limit'] != '') ? $this->_postFields['long_limit'] : 0),
                            'sort_order' => $this->_postFields['sort_order1'] . '|' . $this->_postFields['sort_order2'],
                            'paginate' => $paginate,
                            'section_requests' => 0,
                            'section_access' => $this->_postFields['section_access']);
            $section = new Phire_Table_Sections($fields);

        }

        $section->save();

    }

    /**
     * Method to set the post fields.
     *
     * @param  array $post
     * @return void
     */
    protected function _setFields($post = null)
    {

        if (!is_null($post)) {
            if ((!$_POST) && isset($post['section_id']) && ($post['section_id'] != 0)) {

                $section = new Phire_Table_Sections();
                $section->findById($post['section_id']);

                $sort = Moc10_String::setString($section->sort_order)->split('|');

                $this->_postFields['site_id'] = $section->site_id;
                $this->_postFields['template_id'] = $section->template_id;
                $this->_postFields['parent_section_id'] = $section->parent_section_id;
                $this->_postFields['section_title'] = (string)Moc10_String::setString($section->section_title)->strip()->html();
                $this->_postFields['section_url'] = (string)Moc10_String::setString($section->section_url)->strip()->html();
                $this->_postFields['short_template'] = (string)Moc10_String::setString($section->short_template)->strip()->html();
                $this->_postFields['short_template_container'] = $section->short_template_container;
                $this->_postFields['short_limit'] = (string)Moc10_String::setString($section->short_limit)->strip()->html();
                $this->_postFields['long_template'] = (string)Moc10_String::setString($section->long_template)->strip()->html();
                $this->_postFields['long_template_container'] = $section->long_template_container;
                $this->_postFields['long_limit'] = (string)Moc10_String::setString($section->long_limit)->strip()->html();
                $this->_postFields['sort_order1'] = $sort[0];
                $this->_postFields['sort_order2'] = $sort[1];
                $this->_postFields['paginate'] = (string)Moc10_String::setString($section->paginate)->strip()->html();
                $this->_postFields['section_access'] = $section->section_access;
                $this->_postFields['cur_site_id'] = $this->_postFields['site_id'];
                $this->_postFields['cur_section_url'] = $this->_postFields['section_url'];
                $this->_postFields['plugin'] = (isset($post['plugin'])) ? $post['plugin'] : null;
                $this->_postFields['mobile'] = (isset($post['mobile'])) ? $post['mobile'] : null;
                $this->_postFields['section_id'] = $section->section_id;

            } else {
                foreach ($post as $key => $value) {
                    if (array_key_exists($key, $this->_postFields)) {
                        $this->_postFields[$key] = (isset($post[$key])) ? $post[$key] : null;
                    }
                }
            }
        }

    }

    /**
     * Method to set the form templates.
     *
     * @return void
     */
    protected function _setTemplates()
    {


        $lang = new Phire_Language();
        $back = $lang->__('Back');
        $gen = $lang->__('Generate new URL?');
        $addDate = $lang->__('Add Date?');
        $blue = $lang->__('Blue fields are required.');
        $zero = $lang->__('0 for no limit');
        $pag = $lang->__('Paginate?');
        $cancel = $lang->__('CANCEL');

        if (!is_null($this->_postFields['plugin'])) {
            $plugin = "<input type=\"hidden\" name=\"plugin\" value=\"{$this->_postFields['plugin']}\" />";
            $plg_lnk = BASE_PATH . CONTENT_PATH . "/extensions/plugins/{$this->_postFields['plugin']}/?sys_path=" . BASE_PATH . SYS_PATH;
            $plg_cancel = "&plugin={$this->_postFields['plugin']}";
        } else {
            $plugin = null;
            $plg_lnk = './sections.php';
            $plg_cancel = null;
        }

        if (is_array($this->_postFields['paginate']) && (isset($this->_postFields['paginate'][0])) && ($this->_postFields['paginate'][0] == 'Yes')) {
            $pgChk = "checked=\"checked\" ";
        } else if ($this->_postFields['paginate'] == 'Yes') {
            $pgChk = "checked=\"checked\" ";
        } else {
            $pgChk = "";
        }

        if (($this->_postFields['section_id'] != 0) && ($this->_postFields['site_id'] != 0) && (!is_null($this->_postFields['section_url']))) {
            $site = new Phire_Table_Sites();
            $site->findById($this->_postFields['site_id']);
            $section_link = "http://" . $site->site_domain . BASE_PATH . $this->_postFields['section_url'];
            $view = "<span class=\"right\" style=\"padding: 4px 8px 0 5px;\"><a href=\"{$section_link}\" target=\"_blank\">View</a> <span style=\"padding: 0 5px 0 5px;\">|</span> </span>";
            $generate = "                                    <br /><a id=\"generateLink\" class=\"smallLink\" href=\"#\" onclick=\"addSectionFrm.convertURL('section_title', 'section_url', '" . $site->title_separator  . "'); xmlhttp.getRequest('../core/process/check.section.url.php?current=" . $this->_postFields['cur_section_url'] . "&url=' + addSectionFrm.fo.section_url.value + '&site_id=' + addSectionFrm.fo.site_id.value, addSectionFrm.checkURL);return false;\">{$gen}</a>";
        } else {
            $view = '';
            $generate = '';
        }

        // Define the main form template.
        $this->_templates['main'] = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="{$plg_lnk}">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader">
                    <td class="grayHeader">
                        &nbsp;
                    </td>
                </tr>
                <tr>
                    <td style="padding: 15px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td class="textRight">
                                    <h4 style="float: left;">{$blue}</h4>

                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{template_id_label}]
                                </td>
                                <td class="textRight">
                                    <div id="templateDiv">
                                        [{template_id}]
                                    </div>
                                    [{site_id_label}]
                                    [{site_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{parent_section_id_label}]
                                </td>
                                <td>
                                    <div id="parentSectDiv">
                                        [{parent_section_id}]
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{section_title_label}]
                                </td>
                                <td>
                                    [{section_title}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{section_url_label}]
                                </td>
                                <td>
                                    [{section_url}]
{$generate}
                                    <div id="urlDiv">
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{short_template_label}]
                                </td>
                                <td>
                                    [{short_template}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{short_template_container_label}]
                                </td>
                                <td>
                                    [{short_template_container}]
                                    <span style="padding: 0 10px 0 10px;"></span>
                                    [{short_limit_label}]
                                    [{short_limit}] <em>({$zero})</em>
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{long_template_label}]
                                </td>
                                <td>
                                    [{long_template}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{long_template_container_label}]
                                </td>
                                <td>
                                    <span style="float: right;"><input style="float: left;" type="checkbox" class="checkBox" name="paginate" id="paginate" value="Yes" {$pgChk}/> <span style="float: left; margin: 5px 0 0 5px; font-size: 0.9em;">{$pag}</span></span>
                                    [{long_template_container}]
                                    <span style="padding: 0 10px 0 10px;"></span>
                                    [{long_limit_label}]
                                    [{long_limit}] <em>({$zero})</em>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{sort_order1_label}]
                                </td>
                                <td>
                                    [{sort_order1}]
                                    [{sort_order2}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{section_access_label}]
                                </td>
                                <td>
                                    [{section_access}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    <a style="margin: 0 0 0 10px; padding-top: 6px; height: 19px; font-size: 0.825em; float: right;" class="submitGrayBtn" href="../core/process/add.section.php?action=cancel{$plg_cancel}">{$cancel}</a> [{submit}] {$view} [{section_id}] [{cur_site_id}] [{cur_section_url}] {$plugin}
                                </td>
                            </tr>
                        </table>
                        <script type="text/javascript">
                            addSectionFormInit();
                            var xmlhttp = new JaxXmlHttp();
                        </script>
                    </td>
                </tr>
            </table>
FORMTEMP;

        $mobile = (!is_null($this->_postFields['mobile'])) ? "<input type=\"hidden\" name=\"mobile\" value=\"true\" />" : null;

        // Define the mobile form template.
        $this->_templates['mobile'] = <<<FORMTEMP
            <table id="headerTable" cellpadding="0" cellspacing="0"><tr><td>&lt;&lt;&lt; <a class="orangeLink" href="./sections.php">{$back}</a></td></tr></table>
            <table id="dataAltTable" cellspacing="0" cellpadding="0">
                <tr class="grayHeader" style="height; 16px;">
                    <td class="grayHeader" style="height; 16px;">
                        &nbsp;
                    </td>
                </tr>
                <tr>
                    <td style="padding: 5px;">
                        <table id="entryTable" cellspacing="0" cellpadding="0">
                            <tr>
                                <td>
                                    &nbsp;
                                </td>
                                <td>
                                    <h4>{$blue}</h4>
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{template_id_label}]
                                </td>
                                <td class="textRight">
                                    [{template_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{parent_section_id_label}]
                                </td>
                                <td>
                                    [{parent_section_id}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{section_title_label}]
                                </td>
                                <td>
                                    [{section_title}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{section_url_label}]
                                </td>
                                <td>
                                    [{section_url}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{short_template_label}]
                                </td>
                                <td>
                                    [{short_template}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{short_template_container_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{short_template_container}]
                                    <span style="padding: 0 10px 0 10px;"></span>
                                    [{short_limit_label}]
                                    [{short_limit}]
                                    <br />
                                    <em>({$zero})</em>
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight" style="vertical-align: top;">
                                    [{long_template_label}]
                                </td>
                                <td>
                                    [{long_template}]
                                    <span style="float: left;"><input style="float: left;" type="checkbox" class="checkBox" name="paginate" id="paginate" value="Yes" {$pgChk}/> <span style="float: left; margin: 5px 0 0 5px; font-size: 0.9em;">{$pag}</span></span>
                                </td>
                            </tr>
                            <tr>
                                <td class="textTopRight">
                                    [{long_template_container_label}]
                                </td>
                                <td style="vertical-align: top;">
                                    [{long_template_container}]
                                    <span style="padding: 0 10px 0 10px;"></span>
                                    [{long_limit_label}]
                                    [{long_limit}]
                                    <br />
                                    <em>({$zero})</em>
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{sort_order1_label}]
                                </td>
                                <td>
                                    [{sort_order1}]
                                    [{sort_order2}]
                                </td>
                            </tr>
                            <tr>
                                <td class="textRight">
                                    [{section_access_label}]
                                </td>
                                <td>
                                    [{section_access}]
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    &nbsp;<br />
                                </td>
                            </tr>
                            <tr>
                                <td colspan="2">
                                    <a style="float: right; margin: 0 0 0 5px; padding: 2px 3px 4px 3px; height: 10px; font-size: 0.9em;" class="submitBtnGray" href="../../core/process/add.section.php?action=cancel&mobile=true">{$cancel}</a> [{submit}] [{section_id}] [{site_id}] [{cur_site_id}] [{cur_section_url}] {$mobile}
                                </td>
                            </tr>
                        </table>
                    </td>
                </tr>
            </table>
FORMTEMP;

    }

}
