<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Form_Update
 *
 * @category   Phire
 * @package    Phire_Form
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Form_Update extends Moc10_Form
{

    /**
     * Initialization method for the update form.
     *
     * @param string $ver
     * @return void
     */
    public function init($ver = null)
    {

        $lang = new Phire_Language();

        $this->setAttributes('id', 'updateForm');
        $this->setAttributes('onsubmit', "return updateFrm.validate();");

        $site = new Phire_Table_Sites();
        $site->getSite();

        $add = str_replace('www.', '', $site->site_domain);
        $add = 'ftp.' . $add;

        // Create the 'ftp_address' form element.
        $ftp_address = new Moc10_Form_Element('text', 'ftp_address', $add);
        $ftp_address->setLabel($lang->__('FTP Address:'));
        $ftp_address->setAttributes('size', '30');
        $ftp_address->setRequired(true);

        // Create the 'username' form element.
        $username = new Moc10_Form_Element('text', 'username', null);
        $username->setLabel($lang->__('Username:'));
        $username->setAttributes('size', '30');
        $username->setRequired(true);

        // Create the 'password' form element.
        $password = new Moc10_Form_Element('password', 'password', null);
        $password->setLabel($lang->__('Password:'));
        $password->setAttributes('size', '30');
        $password->setRequired(true);

        // Create the 'ftp_root' form element.
        $ftp_root = new Moc10_Form_Element_Radio('ftp_root', array('Yes' => $lang->__('Logs directly into the document root.'), 'No' => $lang->__('No, change the directory to:') . ' '), 'Yes');
        $ftp_root->setLabel($lang->__('FTP Root:'));

        $cfg = new Phire_Table_Config();

        if (strpos($cfg->settings['system_docroot'], '/') !== false) {
            $doc = '/' . substr($cfg->settings['system_docroot'], (strrpos($cfg->settings['system_docroot'], '/') + 1));
        } else {
            $doc = '/' . substr($cfg->settings['system_docroot'], (strrpos($cfg->settings['system_docroot'], "\\") + 1));
        }

        // Create the 'doc_root' form element.
        $doc_root = new Moc10_Form_Element('text', 'doc_root', $doc);
        $doc_root->setLabel($lang->__('Document Root:'));
        $doc_root->setAttributes('size', '20');
        $doc_root->setAttributes('style', 'margin: -3px 0 0 -10px; float: left;');

        // Create the 'use_pasv' form element.
        $use_pasv = new Moc10_Form_Element_Radio('use_pasv', array('Yes' => $lang->__('Yes'), 'No' => $lang->__('No')), 'Yes');
        $use_pasv->setLabel($lang->__('Use PASV:'));

        // Create the 'protocol' form element.
        $protocol = new Moc10_Form_Element_Radio('protocol', array('FTP' => 'FTP', 'FTPS' => 'FTPS (SSL)'), 'FTP');
        $protocol->setLabel($lang->__('Protocol:'));

        // Create the 'version' form element.
        $version = new Moc10_Form_Element('hidden', 'version', $ver);

        // Create the 'version' form element.
        $current_version = new Moc10_Form_Element('hidden', 'current_version', $cfg->settings['system_version']);

        // Create the 'sys_path' form element.
        $sys_path = new Moc10_Form_Element('hidden', 'sys_path', base64_encode(BASE_PATH . SYS_PATH));

        // Create the 'content_path' form element.
        $content_path = new Moc10_Form_Element('hidden', 'content_path', base64_encode(BASE_PATH . CONTENT_PATH));

        // Create the 'site_domain' form element.
        $site_domain = new Moc10_Form_Element('hidden', 'site_domain', $site->site_domain);

        // Create the 'submit' form element.
        $submit = new Moc10_Form_Element('submit', 'submit', $lang->__('UPDATE'));
        $submit->setAttributes('class', 'submitBtn');

        // Define the form template.
        $tmpl = <<<FORMTEMP
            <style type="text/css">
                .radioPad {
                    float: left;
                    margin: 0;
                    padding: 0 18px 0 4px;
                }
            </style>
            <table id="updateTable" cellspacing="0" cellpadding="0">
                <tr>
                    <td class="textTopRight">
                        [{ftp_address_label}]
                    </td>
                    <td>
                        [{ftp_address}]
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{username_label}]
                    </td>
                    <td>
                        [{username}]
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{password_label}]
                    </td>
                    <td>
                        [{password}]
                    </td>
                </tr>

                <tr>
                    <td class="textTopRight">
                        [{ftp_root_label}]
                    </td>
                    <td>
                        [{ftp_root}] [{doc_root}]
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{use_pasv_label}]
                    </td>
                    <td>
                        [{use_pasv}]
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        [{protocol_label}]
                    </td>
                    <td>
                        [{protocol}]
                    </td>
                </tr>
                <tr>
                    <td class="textTopRight">
                        &nbsp;
                    </td>
                    <td>
                        [{submit}] [{version}] [{current_version}] [{sys_path}] [{content_path}] [{site_domain}]
                    </td>
                </tr>
            </table>
            <script type="text/javascript">
                updateFormInit();
            </script>
FORMTEMP;

        // Set the form template and add the form element objects to the form.
        $this->setTemplate($tmpl);
        $this->addElements(array($ftp_address, $username, $password, $use_pasv, $ftp_root, $doc_root, $protocol, $version, $current_version, $sys_path, $content_path, $site_domain, $submit));

    }

}
