<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Init
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Init
 *
 * @category   Phire
 * @package    Phire_Init
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Init
{

    /**
     * URL request
     * @var string
     */
    protected $_url = null;

    /**
     * Constructor
     *
     * Instantiate the init object.
     *
     * @param  string $url
     * @return void
     */
    public function __construct($url)
    {

        $this->_url = $url;

        try {

            switch ($this->_url) {

                // Process a system user.
                case (substr($this->_url, 0, 5) == '/user'):
                    require_once $_SERVER['DOCUMENT_ROOT'] . '/' . BASE_PATH . SYS_PATH . '/core/process/user.verify.php';
                    break;

                // Process a site search.
                case (substr($this->_url, 0, 7) == '/search'):
                    if (isset($_POST['keywords'])) {
                        $keywords = $_POST['keywords'];
                    } else if (isset($_GET['keywords'])) {
                        $keywords = $_GET['keywords'];
                    } else {
                        $keywords = null;
                    }
                    $search = new Phire_Search($keywords);
                    $search->init();
                    $search->render();
                    break;

                // Process the site feed.
                case (substr($this->_url, 0, 5) == '/feed'):
                    $feed = new Phire_Feed();
                    $feed->render();
                    break;

                // Process a site member.
                case (substr($this->_url, 0, 7) == '/member'):
                    $member = new Phire_Member($this->_url);
                    $member->process();
                    break;

                // Process a site video.
                case (substr($this->_url, 0, 6) == '/video'):
                    $video = new Phire_Video($this->_url);
                    $video->render();
                    break;

                // Process a tag reference.
                case (substr($this->_url, 0, 4) == '/tag'):
                    $tag = new Phire_Tag($this->_url);
                    $tag->init();
                    $tag->render();
                    break;

                // Process an event.
                case (substr($this->_url, 0, 6) == '/event'):
                    $event = new Phire_Event($this->_url);
                    $event->init();
                    $event->render();
                    break;

                // Process a CAPTCHA image.
                case (substr($this->_url, 0, 8) == '/captcha'):
                    $sys = new Phire_Table_Config();
                    $sess = Moc10_Session::getInstance();
                    if (function_exists('imagettftext')) {
                        $image_captcha = new Moc10_Image($sys->settings['system_docroot'] . BASE_PATH . SYS_PATH . '/core/images/captcha_sm.gif');
                        $image_captcha->text($sess->captcha, 20, 20, 38, 8, $sys->settings['system_docroot'] . BASE_PATH . SYS_PATH . '/core/misc/times.ttf');
                    } else {
                        $image_captcha = new Moc10_Image($sys->settings['system_docroot'] . BASE_PATH . SYS_PATH . '/core/images/captcha_sm_lt.gif');
                        $image_captcha->text($sess->captcha, 5, 28, 7);
                    }
                    break;

                // Process a section or page.
                default:

                    // Check for a cache file first.
                    if (file_exists('.' . BASE_PATH . CONTENT_PATH . '/cache/' . sha1($this->_url) . '.txt')) {
                        $page = new Phire_Page($this->_url);
                        $page->init();
                        $page->render();
                    // Else, interact with the database to attempt to find the section or page.
                    } else {
                        $section = new Phire_Table_Sections();
                        $section->getSection($this->_url);

                        // Render the section or page, if found.
                        if (isset($section->section_id)) {
                            $sect = new Phire_Section($this->_url);
                            $sect->init();
                            $sect->render();
                        } else {
                            $page = new Phire_Page($this->_url);
                            $page->init();
                            $page->render();
                        }
                    }

            }

        } catch (Exception $e) {

            $error = new Phire_Error($e);
            $error->init();
            $error->render();

        }

    }

    /**
     * Static method to instantiate the init object.
     *
     * @param  string $u
     * @return Phire_Init
     */
    public static function start($u)
    {

        return new self($u);

    }

}
