<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Parser
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Parser_Event
 *
 * @category   Phire
 * @package    Phire_Parser
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Parser_Event
{

    /**
     * Section matches
     * @var array
     */
    protected $_matches = array();

    /**
     * Section RegEx
     * @var string
     */
    protected $_regex = '/\[\{events_\d*\}\]/';

    /**
     * Content to evaluate
     * @var string
     */
    protected $_content = null;

    /**
     * URL request
     * @var string
     */
    protected $_url = null;

    /**
     * Constructor
     *
     * Instantiate the event parser object.
     *
     * @param  string $content
     * @param  string $url
     * @return void
     */
    public function __construct($content, $url = null)
    {

        // Perform a preg_match_all to look for any event tags within the content, then parse the content.
        $this->_content = $content;
        preg_match_all($this->_regex, $this->_content, $this->_matches);
        $this->_parse();

    }

    /**
     * Static method to instantiate the section parser object
     * and return the parsed string.
     *
     * @param  string $cont
     * @param  string $u
     * @return Phire_Parser_Section
     */
    public static function init($cont, $u = null)
    {

        return new self($cont, $u);

    }

    /**
     * Set content within the content property.
     *
     * @param  string $subject
     * @param  string $replace
     * @return void
     */
    public function setContent($subject, $replace)
    {

        $this->_content = str_replace($subject, $replace, $this->_content);

    }

    /**
     * Get content within the content property.
     *
     * @return string
     */
    public function getContent()
    {

        return $this->_content;

    }

    /**
     * Renders any event elements within the content.
     *
     * @return void
     */
    protected function _parse()
    {

        // If event tag elements are found, format and set in content.
        if (isset($this->_matches[0][0])) {

            foreach ($this->_matches[0] as $value) {

                $section_format = '';
                $section_count = 0;

                $tid = str_replace('[{events_', '', $value);
                $tid = str_replace('}]', '', $tid);

                $events = new Phire_Table_Events();
                $events->findAll('event_start_date, event_start_time ASC', 'type_id', $tid);

                $event_type = new Phire_Table_EventTypes();
                $event_type->findById($tid);

                $site = new Phire_Table_Sites();
                $site->getSite();

                $date_format = $site->default_date_format;
                $time_format = ($site->default_time_format != '') ? ' ' . $site->default_time_format : 'g:i A';

                if (isset($events->rows[0])) {

                    try {

                        $event_format = "        <h3 class=\"eventHeader\">{$event_type->event_type}</h3>\n";

                        foreach ($events->rows as $event) {
                            if ($event->event_start_date != '0000-00-00') {
                                $event_start_date = Moc10_String::setString($event->event_start_date)->date($date_format);
                            } else {
                                $rec = Moc10_String::setString($event->event_recurrence)->split('+');
                                $event_start_date = $rec[0] . ' ' . $rec[1] . ' of the Month';
                            }
                            if ($event->event_end_date != '0000-00-00') {
                                $event_format .= "        <div class=\"eventDiv\"><a class=\"eventLink\" href=\"/event/{$event->event_id}" . Moc10_String::setString($event->event_title)->slug() . "\">{$event->event_title}</a><br />" . $event_start_date . " - " . Moc10_String::setString($event->event_end_date)->date($date_format);
                            } else {
                                $event_format .= "        <div class=\"eventDiv\"><a class=\"eventLink\" href=\"/event/{$event->event_id}" . Moc10_String::setString($event->event_title)->slug() . "\">{$event->event_title}</a><br />" . $event_start_date;
                            }
                            if ($event->event_end_time != '00:00:00') {
                                $event_format .= ", " . Moc10_String::setString($event->event_start_time)->date($time_format) . " to " . Moc10_String::setString($event->event_end_time)->date($time_format);
                            } else {
                                $event_format .= ", " . Moc10_String::setString($event->event_start_time)->date($time_format);
                            }
                            $event_format .= "</div>\n";
                        }

                        $this->setContent($value, $event_format);

                    } catch (Exception $e) {
                        $this->setContent($value, '');
                    }

                } else {
                    $this->setContent($value, '');
                }

            }

        }

    }

}
