<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Table
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Table_Templates
 *
 * @category   Phire
 * @package    Phire_Table
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */


class Phire_Table_Templates extends Moc10_Record
{

    /**
     * Table name of the database table
     * @var string
     */
    protected $_tableName = 'templates';

    /**
     * Primary ID field name of the database table
     * @var string
     */
    protected $_primaryId = 'template_id';

    /**
     * Constructor
     *
     * Instantiate the database record object.
     *
     * @param array  $fields
     * @param string $type
     * @param string $dbase
     * @param string $host
     * @param string $user
     * @param string $pass
     * @throws Exception
     * @return void
     */
    public function __construct($fields = null, $type = null, $db = null, $host = null, $user = null, $pass = null)
    {

        if (!isset($this->_tableName)) {
            throw new Exception('Error: Table name not set.');
        } else {
            $this->_tableName = DB_PREFIX . $this->_tableName;
            parent::__construct($fields, $type, $db, $host, $user, $pass);
        }

    }

    /**
     * Get the template
     *
     * @param  int|string $id
     * @return void
     */
    public function getTemplate($id)
    {

        if (is_numeric($id)) {
            $this->join(DB_PREFIX . 'content_types', 'type_id', null, 'template_id', $id, 1);
        } else {
            $this->join(DB_PREFIX . 'content_types', 'type_id', null, 'template_name', $id, 1);
        }

        if (isset($this->rows[0])) {
            $this->_fields = $this->rows[0];
        } else {
            $this->_fields = null;
        }

    }

}
