<?php
/**
 * Phire CMS
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.TXT.
 * It is also available through the world-wide-web at this URL:
 * http://www.phirecms.org/LICENSE.TXT
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@phirecms.org so we can send you a copy immediately.
 *
 * @category   Phire
 * @package    Phire_Template
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 */

/**
 * Phire_Template
 *
 * @category   Phire
 * @package    Phire_Template
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

class Phire_Template
{

    /**
     * Template type
     * @var string
     */
    protected $_type = null;

    /**
     * Template
     * @var string
     */
    protected $_tmpl = null;

    /**
     * Template ID
     * @var string|int
     */
    protected $_template_id = null;

    /**
     * Constructor
     *
     * Instantiate the template object.
     *
     * @param  int|string $id
     * @throws Exception
     * @return void
     */
    public function __construct($id = null)
    {

        $sess = Moc10_Session::getInstance();
        $mob = new Moc10_Session_Mobile();

        // Handle any mobile flags, if passed.
        if (isset($_GET['mobile'])) {
            switch ($_GET['mobile']) {
                case 'true':
                    $sess->moc10_mobile_bypass = 'FORCE_MOBILE';
                    break;
                case 'false':
                    $sess->moc10_mobile_bypass = 'FORCE_STANDARD';
                    break;
                case 'clear':
                    unset($sess->moc10_mobile_bypass);
                    break;
            }
        }

        // Get a specific template by the passed ID.
        if (!is_null($id)) {

            $tmpl = new Phire_Table_Templates();
            $tmpl->getTemplate($id);

            // Initialize the page template.
            if (!isset($tmpl->template_id)) {
                throw new Exception('Error: Template not found.');
            } else {
                $this->_type = $tmpl->type;
                $this->_template_id = $tmpl->template_id;

                if (($mob->isMobile !== false) && ($tmpl->mobile_template != '')) {
                    $this->_tmpl = (isset($sess->moc10_mobile_bypass) && ($sess->moc10_mobile_bypass == 'FORCE_STANDARD')) ? $tmpl->template : $tmpl->mobile_template;
                } else {
                    $this->_tmpl = (isset($sess->moc10_mobile_bypass) && ($sess->moc10_mobile_bypass == 'FORCE_MOBILE')) ? $tmpl->mobile_template : $tmpl->template;
                }
            }

        // Else, get the site's default template.
        } else {

            $site = new Phire_Table_Sites();
            $site->getSite();

            // Initialize the page template.
            if (!isset($site->site_id)) {
                throw new Exception('Error: Template not found.');
            } else {
                $this->_type = $site->type;

                $cfg = new Phire_Table_Config();
                if ($site->default_template_id > 0) {
                    $tmp = new Phire_Table_Templates();
                    $tmp->findById($site->default_template_id);
                }
                if (($site->default_template_id > 0) && (isset($tmp->template_id))) {
                    $def_tmpl = $tmp->template;
                    $def_mob_tmpl = $tmp->mobile_template;
                    $this->_template_id = $tmp->template_id;
                } else if ($site->default_template_id == 0) {
                    $def_tmpl = $cfg->settings['default_system_template'];
                    $def_mob_tmpl = $cfg->settings['default_system_template'];
                } else if ($site->default_template_id == -1) {
                    $def_tmpl = null;
                    $def_mob_tmpl = null;
                }
                if (($mob->isMobile !== false) && ($def_mob_tmpl != '')) {
                    $this->_tmpl = (isset($sess->moc10_mobile_bypass) && ($sess->moc10_mobile_bypass == 'FORCE_STANDARD')) ? $def_tmpl : $def_mob_tmpl;
                } else {
                    $this->_tmpl = (isset($sess->moc10_mobile_bypass) && ($sess->moc10_mobile_bypass == 'FORCE_MOBILE')) ? $def_mob_tmpl : $def_tmpl;
                }
            }

        }

        $this->_tmpl = Phire_Parser_Template::init($this->_tmpl, $this->_template_id)->getContent();

        $page_matches = array();
        preg_match_all('/\[\{page_\d*\}\]/', $this->_tmpl, $page_matches);

        if (isset($page_matches[0][0])) {
            foreach ($page_matches[0] as $value) {
                $str = substr($value, strpos($value, '[{page_') + 7);
                $id = substr($str, 0, strpos($str, '}'));
                $placeholder = '[{page_' . $id . '}]';
                $pg = new Phire_Table_Pages();
                $pg->findById($id);
                if (isset($pg->page_id)) {
                    $pg_cont = (isset($pg->page_id)) ? $pg->page_content : '';
                } else {
                    $pg_cont = '';
                }
                $this->_tmpl = str_replace($placeholder, $pg_cont, $this->_tmpl);
            }
        }

        if (strpos($this->_tmpl, '[{on}]') !== false) {
            $nav_matches = array();
            preg_match_all('/\[\{on\}\]/', $this->_tmpl, $nav_matches, PREG_OFFSET_CAPTURE);
            if (isset($nav_matches[0][0])) {
                $swapAry = array();
                foreach ($nav_matches[0] as $on) {
                    $href = substr($this->_tmpl, ($on[1] + 14));
                    $href = substr($href, 0, strpos($href, '"'));
                    $str = substr($this->_tmpl, $on[1]);
                    $str = substr($str, 0, (strpos($str, '>') + 1));
                    if ($href == substr($_SERVER['REQUEST_URI'], 0, strlen($href)) && (!$this->_is404)) {
                        $swap = str_replace('[{on}]', 'On', $str);
                    } else {
                        $swap = str_replace('[{on}]', '', $str);
                    }
                    $swapAry[] = array($str, $swap);
                }
                if (count($swapAry) > 0) {
                    foreach ($swapAry as $swp) {
                        $this->_tmpl = str_replace($swp[0], $swp[1], $this->_tmpl);
                    }
                }
            }
        }


    }

    /**
     * Output the template as is.
     *
     * @return string
     */
    public function __toString()
    {

        return $this->_tmpl;

    }

    /**
     * Initialize the template.
     *
     * @param  array $fields
     * @return void
     */
    public function initTemplate($fields = null)
    {

        if (!is_null($fields) && is_array($fields)) {

            foreach ($fields as $key => $value) {
                $this->setContent('[{' . $key . '}]', $value);
            }

        } else {

            $site = new Phire_Table_Sites();
            $site->getSite();

            $this->setContent('[{page_author}]', $site->default_author);
            $this->setContent('[{page_keywords}]', $site->default_keywords);
            $this->setContent('[{page_desc}]', $site->default_desc);
            $this->setContent('[{page_charset}]', $site->charset);
            $this->setContent('[{page_robots}]', $site->robots);
            $this->setContent('[{site_domain}]', $site->site_domain);
            $this->setContent('[{base_path}]', BASE_PATH);
            $this->setContent('[{sys_path}]', SYS_PATH);
            $this->setContent('[{content_path}]', CONTENT_PATH);

        }

    }

    /**
     * Set content within the template.
     *
     * @param  string $subject
     * @param  string $replace
     * @return void
     */
    public function setContent($subject, $replace)
    {

        $this->_tmpl = str_replace($subject, $replace, $this->_tmpl);

    }

    /**
     * Render the template.
     *
     * @return void
     */
    public function render()
    {

        $site = new Phire_Table_Sites();
        $site->getSite();

        $this->_tmpl = Phire_Parser::getParser($this->_tmpl)->getContent();

        if (!isset($_GET['query'])) {
            $_GET['query'] = $_SERVER['PHP_SELF'];
        }

        if (!headers_sent()) {
            header('Content-type: ' . $this->_type);
        }

        $this->_tmpl = Phire_Plugins::init($this->_tmpl, $_GET['query'], $site->site_id, false)->getContent();
        print($this->_tmpl);

    }

    /**
     * Get the template.
     *
     * @return string
     */
    public function getTemplate()
    {

        return $this->_tmpl;

    }

    /**
     * Get the template type.
     *
     * @return string
     */
    public function getTemplateType()
    {

        return $this->_type;

    }

}
