<?php

/**
 * Phire Export Members
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

set_time_limit(0);
require_once '../../bootstrap.php';

try {

    $members = new Phire_Table_Members();
    $num_of_members = 0;
    $limit = 50000;

    $sess = Moc10_Session::getInstance();
    $sitesAry = array();
    foreach ($sess->sites as $site_id) {
        $sitesAry[] = DB_PREFIX . 'sites.site_id = ' . $site_id;
        $num_of_members += $members->getCount($site_id);
    }

    // If there are more members than the limit, break the export file out to multiple files and zip them up for delivery.
    if ($num_of_members > $limit) {

        $num_of_files = floor($num_of_members / $limit);
        if (($num_of_members % $limit) != 0) {
            $num_of_files++;
        }

        $files = array();

        for ($i = 0; $i < $num_of_files; $i++) {
            $sql = "SELECT " . DB_PREFIX . "members.member_id, " . DB_PREFIX . "sites.site_domain, " . DB_PREFIX . "members.username, " . DB_PREFIX . "members.email, " . DB_PREFIX . "members.lname, " . DB_PREFIX . "members.fname, " . DB_PREFIX . "members.address1, " . DB_PREFIX . "members.address2, " . DB_PREFIX . "members.city, " . DB_PREFIX . "members.state, " . DB_PREFIX . "members.zip, " . DB_PREFIX . "members.country, " . DB_PREFIX . "members.phone, " . DB_PREFIX . "members.organization, " . DB_PREFIX . "members.title, " . DB_PREFIX . "members.birth_date, " . DB_PREFIX . "members.gender, " . DB_PREFIX . "members.verified, " . DB_PREFIX . "members.approved, " . DB_PREFIX . "members.receive_updates, " . DB_PREFIX . "members.last_login, " . DB_PREFIX . "members.last_ip FROM " . DB_PREFIX . "members LEFT JOIN " . DB_PREFIX . "sites ON " . DB_PREFIX . "members.site_id = " . DB_PREFIX . "sites.site_id WHERE " . implode(" OR ", $sitesAry) . " ORDER BY site_domain, member_id LIMIT " . ($i * $limit) . ", " . $limit;
            $members = new Phire_Table_Members();
            $members->execute($sql);
            // If members found, export to file or return to the members page.
            if (isset($members->rows[0])) {
                $num = $i + 1;
                $files[] = DB_PREFIX . 'members_' . date('Y-m-d') . '_' . $num . '.csv';
                $file = new Moc10_File($_SERVER['DOCUMENT_ROOT'] . BASE_PATH . CONTENT_PATH . '/phire_members_' . date('Y-m-d') . '_' . $num . '.csv');
                $file->export($members->rows, null, ',', '"', null, false, true);
            }
        }

        $zip = new ZipArchive();
        $res = $zip->open($_SERVER['DOCUMENT_ROOT'] . BASE_PATH . CONTENT_PATH . '/phire_members_' . date('Y-m-d') . '.zip', ZipArchive::CREATE);

        if ($res === true) {
            foreach ($files as $fle) {
                $zip->addFile($_SERVER['DOCUMENT_ROOT'] . BASE_PATH . CONTENT_PATH . '/' . $fle, $fle);
            }
        }

        $zip->close();

        foreach ($files as $fle) {
            if (file_exists($_SERVER['DOCUMENT_ROOT'] . BASE_PATH . CONTENT_PATH . '/' . $fle)) {
                unlink($_SERVER['DOCUMENT_ROOT'] . BASE_PATH . CONTENT_PATH . '/' . $fle);
            }
        }

        header('Location: ' . BASE_PATH . CONTENT_PATH . '/phire_members_' . date('Y-m-d') . '.zip');

    // Else, get export to a single file and deliver.
    } else {

        $sql = "SELECT " . DB_PREFIX . "members.member_id, " . DB_PREFIX . "sites.site_domain, " . DB_PREFIX . "members.username, " . DB_PREFIX . "members.email, " . DB_PREFIX . "members.lname, " . DB_PREFIX . "members.fname, " . DB_PREFIX . "members.address1, " . DB_PREFIX . "members.address2, " . DB_PREFIX . "members.city, " . DB_PREFIX . "members.state, " . DB_PREFIX . "members.zip, " . DB_PREFIX . "members.country, " . DB_PREFIX . "members.phone, " . DB_PREFIX . "members.organization, " . DB_PREFIX . "members.title, " . DB_PREFIX . "members.birth_date, " . DB_PREFIX . "members.gender, " . DB_PREFIX . "members.verified, " . DB_PREFIX . "members.approved, " . DB_PREFIX . "members.receive_updates, " . DB_PREFIX . "members.last_login, " . DB_PREFIX . "members.last_ip FROM " . DB_PREFIX . "members LEFT JOIN " . DB_PREFIX . "sites ON " . DB_PREFIX . "members.site_id = " . DB_PREFIX . "sites.site_id WHERE " . implode(" OR ", $sitesAry) . " ORDER BY site_domain, member_id LIMIT 0, " . $limit;
        $members->execute($sql);

        // If members found, export to file or return to the members page.
        if (isset($members->rows[0])) {
            $file = new Moc10_File(DB_PREFIX . 'members_' . date('Y-m-d') . '.csv');
            $file->export($members->rows, null, ',', '"', null, true, false);
        } else {
            header('Location: ' . BASE_PATH . SYS_PATH . '/system/members.php');
        }

    }

// Else throw a exception/error.
} catch (Exception $e) {

    include_once 'init.php';
    include_once '../includes/error.header.php';
    print("        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 0 0;\">" . $e->getMessage() . "</p>\n");
    include_once '../includes/footer.php';

}

?>
