<?php

/**
 * Phire System ReSync
 *
 * @category   Phire
 * @author     Nick Sagona, III <nick@moc10media.com>
 * @copyright  Copyright (c) 2009-2011 Moc 10 Media, LLC. (http://www.moc10media.com)
 * @license    http://www.phirecms.org/LICENSE.TXT     New BSD License
 * @version    1.1.2
 */

require_once '../../bootstrap.php';

// Initialize system variables.
$server = new Moc10_Session_Server();
$mysqlVersionAry = array();
$system_docroot = $_SERVER['DOCUMENT_ROOT'];

try {

    // Unset current system check flags.
    $sess = Moc10_Session::getInstance();
    $config = new Phire_Table_Config();
    unset($sess->sync_error);
    unset($sess->sys);

    // Create a DB connection, get server software versions.
    $mysqlVersionAry = explode('-', Moc10_Db::getInstance()->interface->version());

    // Reset system configuration values.
    $config->findById('system_docroot');
    $config->value = $system_docroot;
    $config->save();

    $config->findById('server_os');
    $config->value = ($server->distro != 'Unknown') ? $server->os . ' (' . $server->distro . ')' : $server->os;
    $config->save();

    $config->findById('server_software');
    $config->value = $server->software;
    $config->save();

    $config->findById('mysql_version');
    $config->value = trim(str_ireplace('mysql', '', $mysqlVersionAry[0]));
    $config->save();

    $config->findById('php_version');
    $config->value = $server->php;
    $config->save();

    $config->findById('updated_on');
    $config->value = date('Y-m-d H:i:s');
    $config->save();

    // Reset main site domain and docroot.
    $site = new Phire_Table_Sites();
    $site->findById(2001);
    $site->site_domain = $_SERVER['HTTP_HOST'];
    $site->site_docroot = $_SERVER['DOCUMENT_ROOT'];
    $site->save();

    // Test and reset current system check flags.
    require_once 'server.check.php';

    header('Location: ' . BASE_PATH . SYS_PATH . '/system/configuration.php?action=synced');

} catch (Exception $e) {

    include_once substr(BASE_PATH . SYS_PATH, 1) . '/core/process/init.php';
    include_once substr(BASE_PATH . SYS_PATH, 1) . '/core/includes/error.header.php';
    print("        <p style=\"width: 95%; margin: 0 auto; padding: 5px 0 0 0;\">" . $e->getMessage() . "</p>\n");
    include_once substr(BASE_PATH . SYS_PATH, 1) . '/core/includes/footer.php';

}

?>